/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten;

import java.util.Arrays;

import org.junit.Assert;
import org.junit.Test;

import de.bsvrz.ibv.uda.interpreter.OperandenListe;
import de.bsvrz.ibv.uda.interpreter.daten.fehler.ArgumentFehler;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Operator;
import de.bsvrz.sys.funclib.bitctrl.interpreter.logik.LogischerWert;

/**
 * Testet die Ausführung der GROESSER-GLEICH-Operation innerhalb des
 * Arithmetikhandlers.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class ArithmetikHandlerGroesserGleich {

	/**
	 * der verwendete Handler.
	 */
	private static final ArithmetikHandler HANDLER = new ArithmetikHandler();

	/**
	 * der Divisionsoperator.
	 */
	private static final Operator OPERATOR = ArithmetikOperators.GROESSER_GLEICH;

	/**
	 * Ausführung der Operation ohne Operanden.
	 */
	@Test(expected = ArgumentFehler.class)
	public void keineOperanden() {
		ArithmetikHandlerGroesserGleich.HANDLER.perform(ArithmetikHandlerGroesserGleich.OPERATOR, OperandenListe.get());
	}

	/**
	 * Ausführung der Operation mit zu wenigen Operanden.
	 */
	@Test(expected = ArgumentFehler.class)
	public void zuwenigOperanden() {
		ArithmetikHandlerGroesserGleich.HANDLER.perform(ArithmetikHandlerGroesserGleich.OPERATOR,
				OperandenListe.get(12));
	}

	/**
	 * Ausführung der Operation.
	 */
	@Test
	public void testGroesserGleich() {
		Object result = ArithmetikHandlerGroesserGleich.HANDLER.perform(ArithmetikHandlerGroesserGleich.OPERATOR,
				OperandenListe.get(12, 13));
		Assert.assertEquals("Ergebnis ist nicht korrekt", false,
				((LogischerWert) result).getBoolWert());

		result = ArithmetikHandlerGroesserGleich.HANDLER.perform(ArithmetikHandlerGroesserGleich.OPERATOR,
				OperandenListe.get(12, 13.0));
		Assert.assertEquals("Ergebnis ist nicht korrekt", false,
				((LogischerWert) result).getBoolWert());

		result = ArithmetikHandlerGroesserGleich.HANDLER.perform(ArithmetikHandlerGroesserGleich.OPERATOR,
				OperandenListe.get(12.0, 13));
		Assert.assertEquals("Ergebnis ist nicht korrekt", false,
				((LogischerWert) result).getBoolWert());

		result = ArithmetikHandlerGroesserGleich.HANDLER.perform(ArithmetikHandlerGroesserGleich.OPERATOR,
				OperandenListe.get(12.0, 13.0));
		Assert.assertEquals("Ergebnis ist nicht korrekt", false,
				((LogischerWert) result).getBoolWert());

	}

	/**
	 * Ausführung der Operation mit zu vielen Argumenten.
	 */
	@Test(expected = ArgumentFehler.class)
	public void zuvieleOperanden() {
		ArithmetikHandlerGroesserGleich.HANDLER.perform(ArithmetikHandlerGroesserGleich.OPERATOR,
				OperandenListe.get(12, 13, 14));
	}

	/**
	 * Ausführung der Operation mit Operanden vom falschen Typ.
	 */
	@Test(expected = ArgumentFehler.class)
	public void falscheOperanden() {
		ArithmetikHandlerGroesserGleich.HANDLER.perform(ArithmetikHandlerGroesserGleich.OPERATOR,
				OperandenListe.get("Ein Text"));
	}

	/**
	 * ermittelt, ob die erwarteten Operatoren vom Handler unterstützt werden.
	 */
	@Test
	public void testGetHandledOperators() {
		Assert.assertFalse("Anzahl der Operatoren ist 0", 0 == ArithmetikHandlerGroesserGleich.HANDLER
				.getHandledOperators().length);
		Assert.assertTrue(Arrays.asList(ArithmetikHandlerGroesserGleich.HANDLER.getHandledOperators())
				.contains(ArithmetikHandlerGroesserGleich.OPERATOR));
	}

	/**
	 * testet die Funktion validiereHandler für verschiedene
	 * Operandenkombinationen.
	 */
	@Test
	public void testIsHandlerOperatorListOfQextendsObject() {
		Assert.assertFalse(ArithmetikHandlerGroesserGleich.HANDLER
				.validiereHandler(ArithmetikHandlerGroesserGleich.OPERATOR, OperandenListe.get()).isValid());
		Assert.assertFalse(ArithmetikHandlerGroesserGleich.HANDLER
				.validiereHandler(ArithmetikHandlerGroesserGleich.OPERATOR, OperandenListe.get(12.0)).isValid());
		Assert.assertFalse(ArithmetikHandlerGroesserGleich.HANDLER
				.validiereHandler(ArithmetikHandlerGroesserGleich.OPERATOR, OperandenListe.get(12)).isValid());
		Assert.assertFalse(ArithmetikHandlerGroesserGleich.HANDLER
				.validiereHandler(ArithmetikHandlerGroesserGleich.OPERATOR, OperandenListe.get("Ein Text")).isValid());
		Assert.assertFalse(ArithmetikHandlerGroesserGleich.HANDLER
				.validiereHandler(ArithmetikHandlerGroesserGleich.OPERATOR, OperandenListe.get(12, 13, 14)).isValid());
		Assert.assertTrue(ArithmetikHandlerGroesserGleich.HANDLER
				.validiereHandler(ArithmetikHandlerGroesserGleich.OPERATOR, OperandenListe.get(12.0, 13.0)).isValid());
		Assert.assertTrue(ArithmetikHandlerGroesserGleich.HANDLER
				.validiereHandler(ArithmetikHandlerGroesserGleich.OPERATOR, OperandenListe.get(12.0, 13)).isValid());
		Assert.assertTrue(ArithmetikHandlerGroesserGleich.HANDLER
				.validiereHandler(ArithmetikHandlerGroesserGleich.OPERATOR, OperandenListe.get(12, 13.0)).isValid());
		Assert.assertTrue(ArithmetikHandlerGroesserGleich.HANDLER
				.validiereHandler(ArithmetikHandlerGroesserGleich.OPERATOR, OperandenListe.get(12, 13)).isValid());
	}
}
