/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten;

import java.util.Arrays;

import org.junit.Assert;
import org.junit.Test;

import de.bsvrz.ibv.uda.interpreter.OperandenListe;
import de.bsvrz.ibv.uda.interpreter.daten.fehler.ArgumentFehler;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Operator;

/**
 * Testet die Ausführung der Subtraktion innerhalb des Arithmetikhandlers.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class ArithmetikHandlerSubtraktion {

	/**
	 * der verwendete Handler.
	 */
	private static final ArithmetikHandler HANDLER = new ArithmetikHandler();

	/**
	 * der Subtraktionsoperator.
	 */
	private static final Operator OPERATOR = ArithmetikOperators.SUBTRAKTION;

	/**
	 * Ausführung der Operation ohne Operanden.
	 */
	@Test(expected = ArgumentFehler.class)
	public void keineOperanden() {
		ArithmetikHandlerSubtraktion.HANDLER.perform(ArithmetikHandlerSubtraktion.OPERATOR, OperandenListe.get());
	}

	/**
	 * Ausführung der Subtraktion.
	 */
	@Test
	public void testSubtraktion() {
		Object result = ArithmetikHandlerSubtraktion.HANDLER.perform(ArithmetikHandlerSubtraktion.OPERATOR,
				OperandenListe.get(12, 13));
		Assert.assertEquals("Summe ist nicht korrekt", -1L, result);
		Assert.assertEquals("Addition liefert keine Ganzzahl", Long.class, result
				.getClass());

		result = ArithmetikHandlerSubtraktion.HANDLER.perform(ArithmetikHandlerSubtraktion.OPERATOR,
				OperandenListe.get(12, 13.0));
		Assert.assertEquals("Summe ist nicht korrekt", -1.0, result);
		Assert.assertEquals("Addition liefert keine Fließkommazahl", Double.class,
				result.getClass());

		result = ArithmetikHandlerSubtraktion.HANDLER.perform(ArithmetikHandlerSubtraktion.OPERATOR,
				OperandenListe.get(12.0, 13));
		Assert.assertEquals("Summe ist nicht korrekt", -1.0, result);
		Assert.assertEquals("Addition liefert keine Fließkommazahl", Double.class,
				result.getClass());

		result = ArithmetikHandlerSubtraktion.HANDLER.perform(ArithmetikHandlerSubtraktion.OPERATOR,
				OperandenListe.get(12.0, 13.0));
		Assert.assertEquals("Summe ist nicht korrekt", -1.0, result);
		Assert.assertEquals("Addition liefert keine Fließkommazahl", Double.class,
				result.getClass());

		result = ArithmetikHandlerSubtraktion.HANDLER.perform(ArithmetikHandlerSubtraktion.OPERATOR, 12);
		Assert.assertEquals("Ergebnis ist nicht korrekt", -12L, result);

		result = ArithmetikHandlerSubtraktion.HANDLER.perform(ArithmetikHandlerSubtraktion.OPERATOR, -12);
		Assert.assertEquals("Ergebnis ist nicht korrekt", 12L, result);

		result = ArithmetikHandlerSubtraktion.HANDLER.perform(ArithmetikHandlerSubtraktion.OPERATOR, 12.0);
		Assert.assertEquals("Ergebnis ist nicht korrekt", -12.0, result);

		result = ArithmetikHandlerSubtraktion.HANDLER.perform(ArithmetikHandlerSubtraktion.OPERATOR, -12.0);
		Assert.assertEquals("Ergebnis ist nicht korrekt", 12.0, result);
	}

	/**
	 * Ausführung der Operation mit zu vielen Argumenten.
	 */
	@Test(expected = ArgumentFehler.class)
	public void zuvieleOperanden() {
		ArithmetikHandlerSubtraktion.HANDLER.perform(ArithmetikHandlerSubtraktion.OPERATOR,
				OperandenListe.get(12, 13, 14));
	}

	/**
	 * Ausführung der Operation mit Operanden vom falschen Typ.
	 */
	@Test(expected = ArgumentFehler.class)
	public void falscheOperanden() {
		ArithmetikHandlerSubtraktion.HANDLER.perform(ArithmetikHandlerSubtraktion.OPERATOR,
				OperandenListe.get("Ein Text"));
	}

	/**
	 * ermittelt, ob die erwarteten Operatoren vom Handler unterstützt werden.
	 */
	@Test
	public void testGetHandledOperators() {
		Assert.assertFalse("Anzahl der Operatoren ist 0", 0 == ArithmetikHandlerSubtraktion.HANDLER
				.getHandledOperators().length);
		Assert.assertTrue(Arrays.asList(ArithmetikHandlerSubtraktion.HANDLER.getHandledOperators())
				.contains(ArithmetikHandlerSubtraktion.OPERATOR));
	}

	/**
	 * testet die Funktion validiereHandler für verschiedene
	 * Operandenkombinationen.
	 */
	@Test
	public void testIsHandlerOperatorListOfQextendsObject() {
		Assert.assertFalse(ArithmetikHandlerSubtraktion.HANDLER
				.validiereHandler(ArithmetikHandlerSubtraktion.OPERATOR, OperandenListe.get()).isValid());
		Assert.assertTrue(ArithmetikHandlerSubtraktion.HANDLER
				.validiereHandler(ArithmetikHandlerSubtraktion.OPERATOR, OperandenListe.get(12.0)).isValid());
		Assert.assertTrue(ArithmetikHandlerSubtraktion.HANDLER
				.validiereHandler(ArithmetikHandlerSubtraktion.OPERATOR, OperandenListe.get(12)).isValid());
		Assert.assertFalse(ArithmetikHandlerSubtraktion.HANDLER
				.validiereHandler(ArithmetikHandlerSubtraktion.OPERATOR, OperandenListe.get("Ein Text")).isValid());
		Assert.assertFalse(ArithmetikHandlerSubtraktion.HANDLER
				.validiereHandler(ArithmetikHandlerSubtraktion.OPERATOR, OperandenListe.get(12, 13, 14)).isValid());
		Assert.assertTrue(ArithmetikHandlerSubtraktion.HANDLER
				.validiereHandler(ArithmetikHandlerSubtraktion.OPERATOR, OperandenListe.get(12.0, 13.0)).isValid());
		Assert.assertTrue(ArithmetikHandlerSubtraktion.HANDLER
				.validiereHandler(ArithmetikHandlerSubtraktion.OPERATOR, OperandenListe.get(12.0, 13)).isValid());
		Assert.assertTrue(ArithmetikHandlerSubtraktion.HANDLER
				.validiereHandler(ArithmetikHandlerSubtraktion.OPERATOR, OperandenListe.get(12, 13.0)).isValid());
		Assert.assertTrue(ArithmetikHandlerSubtraktion.HANDLER
				.validiereHandler(ArithmetikHandlerSubtraktion.OPERATOR, OperandenListe.get(12, 13)).isValid());
	}
}
