/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.container;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;

import de.bsvrz.ibv.uda.interpreter.daten.konstante.ZeichenkettenLiteral;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Kontext;

/**
 * ein Ausdruck, der eine bedingte Auswahl aus einem Container beschreibt.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class ContainerSelektorSymbol implements Ausdruck {

	/**
	 * die Bedingungen für die Auswahl der Elemente.
	 */
	private final Map<String, Ausdruck> bedingungen = new HashMap<>();

	/**
	 * fügt dem Symbol eine Bedingung hinzu.
	 *
	 * @param name
	 *            der Name des Felds, für das die Bedingung gelten soll
	 * @param ausdruck
	 *            der Ausdruck, der die Bedingung beschreibt
	 */
	public void addBedingung(final String name, final Ausdruck ausdruck) {
		bedingungen.put(name, ausdruck);
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck#interpret(de.bsvrz.sys.funclib.bitctrl.interpreter.Kontext)
	 */
	@Override
	public Object interpret(final Kontext kontext) {
		final SelektionsBedingung result = new SelektionsBedingung();
		for (final Entry<String, Ausdruck> entry : bedingungen.entrySet()) {
			result.addItem(entry.getKey(), entry.getValue().interpret(kontext));
		}
		return result;
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck#getNachfolger()
	 */
	@Override
	public List<Ausdruck> getNachfolger() {
		final List<Ausdruck> liste = new ArrayList<>();
		for (final Entry<String, Ausdruck> eintrag : bedingungen.entrySet()) {
			liste.add(new ZeichenkettenLiteral(eintrag.getKey()));
			liste.add(eintrag.getValue());
		}
		return liste;
	}
}
