/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.konstante;

import java.util.List;

import de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Kontext;

/**
 * Die Repräsentation eines Literals für einen Fliesskomma-Zahlenwert innerhalb
 * des Uda-Interpreterbaumes.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class FliessKommaZahlLiteral implements ZahlenLiteral {

	/**
	 * der Wert des Literals.
	 */
	private final double zahlenWert;

	/**
	 * Konstruktor mit dem Wert, den das Literal repräsentieren soll.
	 *
	 * @param wert
	 *            der Wert
	 */
	public FliessKommaZahlLiteral(final double wert) {
		zahlenWert = wert;
	}

	/**
	 * Die Auswertung des Ausdrucks liefert in jedem Fall eine Instanz der
	 * Klasse <i>Double</i>.
	 *
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.ibv.uda.interpreter.daten.konstante.ZahlenLiteral#interpret(de.bsvrz.sys.funclib.bitctrl.interpreter.Kontext)
	 */
	@Override
	public final Number interpret(final Kontext kontext) {
		return zahlenWert;
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Literal#getWert()
	 */
	@Override
	public Number getWert() {
		return zahlenWert;
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck#getNachfolger()
	 */
	@Override
	public List<Ausdruck> getNachfolger() {
		return null;
	}
}
