/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.konstante;

import java.util.List;

import com.bitctrl.Constants;

import de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck;
import de.bsvrz.sys.funclib.bitctrl.interpreter.InterpreterException;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Kontext;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Literal;

/**
 * Die Repräsentation eines Literals für eine Zeichenkette innerhalb des
 * Uda-Interpreterbaumes.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class ZeichenkettenLiteral implements Literal {

	/**
	 * der Wert des Literals.
	 */
	private String zeichenKette;

	/**
	 * Konstruktor mit Angabe der repräsentierten Zeichenkette. Die Zeichenkette
	 * wird wie übergeben repräsentiert, lediglich folgende Sonderzeichen der
	 * übergebenen Zeichenkette werden ersetzt:
	 * <ol>
	 * <li>'\\' wird durch '\' ersetzt
	 * <li>'\"' wird durch das Zeichen '"' ersetzt
	 * <li>'\n' ergibt einen Zeilenumbruch
	 * </ol>
	 *
	 * Als Parameter wird die Zeichenkette einschließlich der umgebenden '"' aus
	 * dem Skripttext erwartet, d.h. das erste und letzte Zeichen des
	 * ï¿½bergebenen Strings wird entfernt.
	 *
	 * @param text
	 *            die Zeichenkette.
	 * @throws InterpreterException
	 *             die übergebene Zeichenkette wird nicht mit dem Zeichen '"'
	 *             begonnen und beendet
	 */
	public ZeichenkettenLiteral(final String text) {
		if ((text == null) || (!text.startsWith("\""))
				|| (!text.endsWith("\""))) {
			throw new InterpreterException("Aus der übergeben Zeichenkette "
					+ text + " kann kein ZeichenkettenLiteral gebildet werden.");
		}
		final StringBuffer buffer = new StringBuffer(text.substring(1));
		buffer.setLength(buffer.length() - 1);
		zeichenKette = buffer.toString();
		zeichenKette = zeichenKette.replace("\\\"", "\"");
		zeichenKette = zeichenKette.replace("\\\\", "\\");
		zeichenKette = zeichenKette.replace("\\n", Constants.NL);
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck#getNachfolger()
	 */
	@Override
	public List<Ausdruck> getNachfolger() {
		return null;
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Literal#getWert()
	 */
	@Override
	public String getWert() {
		return zeichenKette;
	}

	/**
	 * Die Auswertung des Ausdrucks liefert in jedem Fall eine Instanz der
	 * Klasse <i>String</i>.
	 *
	 * @param kontext
	 *            der Kontext, in dem der Ausdruck ausgewertet wird
	 * @return die Zeichenkette, die der Ausdruck repräsentiert
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck#interpret(de.bsvrz.sys.funclib.bitctrl.interpreter.Kontext)
	 */
	@Override
	public final String interpret(final Kontext kontext) {
		return zeichenKette;
	}
}
