/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.trend;

import java.util.Arrays;
import java.util.Date;
import java.util.List;

import org.junit.Assert;
import org.junit.Test;

import de.bsvrz.ibv.uda.interpreter.OperandenListe;
import de.bsvrz.ibv.uda.interpreter.daten.fehler.ArgumentFehler;
import de.bsvrz.ibv.uda.interpreter.daten.zeit.ZeitDauer;
import de.bsvrz.ibv.uda.interpreter.daten.zeit.Zeitstempel;
import de.bsvrz.sys.funclib.bitctrl.interpreter.NichtWert;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Operator;
import de.bsvrz.sys.funclib.bitctrl.interpreter.logik.LogischerWert;

/**
 * Testklasse für den Test der Klasse: {@link TrendHandler}.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class TrendHandlerTest {

	/**
	 * der verwendete Handler.
	 */
	private static final TrendHandler HANDLER = new TrendHandler();

	/**
	 * der jeweils zu testende Operator.
	 */
	private Operator operator;

	/**
	 * prüft, ob alle erwarteten Operatoren behandelt werden.
	 */
	@Test
	public void testGetHandledOperators() {
		final List<Operator> operatoren = Arrays.asList(TrendHandlerTest.HANDLER.getHandledOperators());
		Assert.assertTrue(operatoren.contains(TrendOperatoren.KONSTRUKTOR));
		Assert.assertTrue(operatoren.contains(TrendOperatoren.BEZUG));
		Assert.assertTrue(operatoren.contains(TrendOperatoren.WERT));
		Assert.assertTrue(operatoren.contains(TrendOperatoren.ZEIT));
		Assert.assertTrue(operatoren.contains(TrendOperatoren.MAXFALLEND));
		Assert.assertTrue(operatoren.contains(TrendOperatoren.MAXSTEIGEND));
		Assert.assertTrue(operatoren.contains(TrendOperatoren.MAXKONSTANT));
		Assert.assertTrue(operatoren.contains(TrendOperatoren.STEIGEND));
		Assert.assertTrue(operatoren.contains(TrendOperatoren.FALLEND));
		Assert.assertTrue(operatoren.contains(TrendOperatoren.KONSTANT));
		Assert.assertTrue(operatoren.contains(TrendOperatoren.ANZAHL));
	}

	/**
	 * testet die validiereHandler-Funktion für den Konstruktor.
	 */
	@Test
	public void testIsHandlerKonstruktor() {
		operator = TrendOperatoren.KONSTRUKTOR;
		Assert.assertTrue(TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get()).isValid());
		Assert.assertTrue(
				TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get(new Object())).isValid());
		Assert.assertFalse(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new Object(), new Object())).isValid());
		Assert.assertTrue(
				TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get(new Object(), 25)).isValid());
		Assert.assertFalse(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new Object(), 25, new Object())).isValid());
	}

	/**
	 * testet die validiereHandler-Funktion für die Operation "bezug".
	 */
	@Test
	public void testIsHandlerBezug() {
		operator = TrendOperatoren.BEZUG;
		Assert.assertFalse(TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get()).isValid());
		Assert.assertFalse(
				TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get(new Object())).isValid());
		Assert.assertTrue(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0))).isValid());
		Assert.assertFalse(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0), new Object())).isValid());
	}

	/**
	 * testet die validiereHandler-Funktion für die Operation "anzahl".
	 */
	@Test
	public void testIsHandlerAnzahl() {
		operator = TrendOperatoren.ANZAHL;
		Assert.assertFalse(TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get()).isValid());
		Assert.assertFalse(
				TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get(new Object())).isValid());
		Assert.assertTrue(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0))).isValid());
		Assert.assertFalse(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0), new Object())).isValid());
	}

	/**
	 * testet die validiereHandler-Funktion für die Operation "wert".
	 */
	@Test
	public void testIsHandlerWert() {
		operator = TrendOperatoren.WERT;
		Assert.assertFalse(TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get()).isValid());
		Assert.assertFalse(
				TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get(new Object())).isValid());
		Assert.assertTrue(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0))).isValid());
		Assert.assertFalse(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0), new Object())).isValid());
		Assert.assertTrue(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0), 25)).isValid());
		Assert.assertFalse(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0), 25, new Object())).isValid());
		Assert.assertTrue(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0), 25, new Zeitstempel()))
				.isValid());
	}

	/**
	 * testet die validiereHandler-Funktion für die Operation "zeit".
	 */
	@Test
	public void testIsHandlerZeit() {
		operator = TrendOperatoren.ZEIT;
		Assert.assertFalse(TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get()).isValid());
		Assert.assertFalse(
				TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get(new Object())).isValid());
		Assert.assertTrue(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0))).isValid());
		Assert.assertFalse(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0), new Object())).isValid());
	}

	/**
	 * testet die validiereHandler-Funktion für die Operation "maxFallend".
	 */
	@Test
	public void testIsHandlerMaxFallend() {
		operator = TrendOperatoren.MAXFALLEND;
		Assert.assertFalse(TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get()).isValid());
		Assert.assertFalse(
				TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get(new Object())).isValid());
		Assert.assertTrue(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0))).isValid());
		Assert.assertFalse(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0), new Object())).isValid());
	}

	/**
	 * testet die validiereHandler-Funktion für die Operation "maxSteigend".
	 */
	@Test
	public void testIsHandlerMaxSteigend() {
		operator = TrendOperatoren.MAXSTEIGEND;
		Assert.assertFalse(TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get()).isValid());
		Assert.assertFalse(
				TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get(new Object())).isValid());
		Assert.assertTrue(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0))).isValid());
		Assert.assertFalse(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0), new Object())).isValid());
	}

	/**
	 * testet die validiereHandler-Funktion für die Operation "maxKonstant".
	 */
	@Test
	public void testIsHandlerMaxKonstant() {
		operator = TrendOperatoren.MAXKONSTANT;
		Assert.assertFalse(TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get()).isValid());
		Assert.assertFalse(
				TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get(new Object())).isValid());
		Assert.assertTrue(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0))).isValid());
		Assert.assertFalse(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0), new Object())).isValid());
	}

	/**
	 * testet die validiereHandler-Funktion für die Operation "steigend".
	 */
	@Test
	public void testIsHandlerSteigend() {
		operator = TrendOperatoren.STEIGEND;
		Assert.assertFalse(TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get()).isValid());
		Assert.assertFalse(
				TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get(new Object())).isValid());
		Assert.assertTrue(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0))).isValid());
		Assert.assertFalse(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0), new Object())).isValid());
		Assert.assertTrue(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0), 25)).isValid());
		Assert.assertTrue(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0), new ZeitDauer(0L))).isValid());
		Assert.assertFalse(
				TrendHandlerTest.HANDLER
				.validiereHandler(operator,
						OperandenListe.get(new TrendObjekt(null, 0), new ZeitDauer(0L), new Object()))
				.isValid());
		Assert.assertTrue(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0), 25, new Zeitstempel()))
				.isValid());
		Assert.assertTrue(
				TrendHandlerTest.HANDLER
				.validiereHandler(operator,
						OperandenListe.get(new TrendObjekt(null, 0), new ZeitDauer(0), new Zeitstempel()))
				.isValid());
	}

	/**
	 * testet die validiereHandler-Funktion für die Operation "fallend".
	 */
	@Test
	public void testIsHandlerFallend() {
		operator = TrendOperatoren.FALLEND;
		Assert.assertFalse(TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get()).isValid());
		Assert.assertFalse(
				TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get(new Object())).isValid());
		Assert.assertTrue(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0))).isValid());
		Assert.assertFalse(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0), new Object())).isValid());
		Assert.assertTrue(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0), 25)).isValid());
		Assert.assertTrue(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0), new ZeitDauer(0L))).isValid());
		Assert.assertFalse(
				TrendHandlerTest.HANDLER
				.validiereHandler(operator,
						OperandenListe.get(new TrendObjekt(null, 0), new ZeitDauer(0L), new Object()))
				.isValid());
		Assert.assertTrue(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0), 25, new Zeitstempel()))
				.isValid());
		Assert.assertTrue(
				TrendHandlerTest.HANDLER
				.validiereHandler(operator,
						OperandenListe.get(new TrendObjekt(null, 0), new ZeitDauer(0L), new Zeitstempel()))
				.isValid());
	}

	/**
	 * testet die validiereHandler-Funktion für die Operation "konstant".
	 */
	@Test
	public void testIsHandlerKonstant() {
		operator = TrendOperatoren.KONSTANT;
		Assert.assertFalse(TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get()).isValid());
		Assert.assertFalse(
				TrendHandlerTest.HANDLER.validiereHandler(operator, OperandenListe.get(new Object())).isValid());
		Assert.assertTrue(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0))).isValid());
		Assert.assertFalse(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0), new Object())).isValid());
		Assert.assertTrue(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0), 25)).isValid());
		Assert.assertTrue(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0), new ZeitDauer(0L))).isValid());
		Assert.assertFalse(
				TrendHandlerTest.HANDLER
				.validiereHandler(operator,
						OperandenListe.get(new TrendObjekt(null, 0), new ZeitDauer(0L), new Object()))
				.isValid());
		Assert.assertTrue(TrendHandlerTest.HANDLER
				.validiereHandler(operator, OperandenListe.get(new TrendObjekt(null, 0), 25, new Zeitstempel()))
				.isValid());
		Assert.assertTrue(
				TrendHandlerTest.HANDLER
				.validiereHandler(operator,
						OperandenListe.get(new TrendObjekt(null, 0), new ZeitDauer(0L), new Zeitstempel()))
				.isValid());
	}

	/**
	 * testet die Ausführung des Konstruktors.
	 */
	@Test
	public void testPerformKonstruktor() {
		operator = TrendOperatoren.KONSTRUKTOR;
		Assert.assertTrue(TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get()) instanceof TrendObjekt);
		Assert.assertTrue(
				TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(new Object())) instanceof TrendObjekt);
		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(new Object(), new Object()));
			Assert.fail("Objekt erzeugt");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
		Assert.assertTrue(TrendHandlerTest.HANDLER.perform(operator,
				OperandenListe.get(new Object(), 25)) instanceof TrendObjekt);
		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(new Object(), 25, new Object()));
			Assert.fail("Objekt erzeugt");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
	}

	/**
	 * testet die Ausführung des Operation "bezug".
	 */
	@Test
	public void testPerformBezug() {
		operator = TrendOperatoren.BEZUG;
		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get());
			Assert.fail("Bezug geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}

		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(new Object()));
			Assert.fail("Bezug geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
		Assert.assertEquals(NichtWert.NICHTWERT,
				TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(new TrendObjekt(null, 0))));
		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(new TrendObjekt(null, 0), new Object()));
			Assert.fail("Bezug geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
	}

	/**
	 * testet die Ausführung des Operation "anzahl".
	 */
	@Test
	public void testPerformAnzahl() {
		operator = TrendOperatoren.ANZAHL;
		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get());
			Assert.fail("Anzahl geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}

		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(new Object()));
			Assert.fail("Anzahl geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
		final TrendObjekt trend = new TrendObjekt(null, 0);
		Assert.assertEquals(0,
				((Number) TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(trend))).intValue());
		trend.addWert(12, null);
		Assert.assertEquals(1,
				((Number) TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(trend))).intValue());
		trend.addWert(12, null);
		Assert.assertEquals(2,
				((Number) TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(trend))).intValue());

		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(trend, new Object()));
			Assert.fail("Anzahl geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
	}

	/**
	 * testet die Ausführung des Operation "wert".
	 */
	@Test
	public void testPerformWert() {
		final TrendObjekt trend = new TrendObjekt(null, 0);
		operator = TrendOperatoren.WERT;
		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get());
			Assert.fail("Wert geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(new Object()));
			Assert.fail("Wert geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
		Assert.assertEquals(NichtWert.NICHTWERT, TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(trend)));

		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(trend, new Object()));
			Assert.fail("Wert geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
		TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(trend, 25));
		Assert.assertEquals(25, ((Number) trend.getWert()).intValue());

		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(trend, 25, new Object()));
			Assert.fail("Wert geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
		final long now = new Date().getTime();
		TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(trend, 25, new Zeitstempel(now + 20000)));
		Assert.assertEquals(now + 20000, ((Zeitstempel) trend.getZeit()).getMilliSekunden());
	}

	/**
	 * testet die Ausführung des Operation "zeit".
	 */
	@Test
	public void testPerformZeit() {
		operator = TrendOperatoren.ZEIT;
		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get());
			Assert.fail("Zeit geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(new Object()));
			Assert.fail("Zeit geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
		Assert.assertEquals(NichtWert.NICHTWERT,
				TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(new TrendObjekt(null, 0))));

		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(new TrendObjekt(null, 0), new Object()));
			Assert.fail("Zeit geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
	}

	/**
	 * testet die Ausführung des Operation "maxFallend".
	 */
	@Test
	public void testPerformMaxFallend() {
		operator = TrendOperatoren.MAXFALLEND;
		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get());
			Assert.fail("Max fallend geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(new Object()));
			Assert.fail("Max fallend geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
		Assert.assertEquals(0L,
				TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(new TrendObjekt(null, 0))));

		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(new TrendObjekt(null, 0), new Object()));
			Assert.fail("Max fallend geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
	}

	/**
	 * testet die Ausführung des Operation "maxSteigend".
	 */
	@Test
	public void testPerformMaxSteigend() {
		operator = TrendOperatoren.MAXSTEIGEND;
		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get());
			Assert.fail("Max steigend geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(new Object()));
			Assert.fail("Max steigend geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
		Assert.assertEquals(0L,
				TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(new TrendObjekt(null, 0))));

		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(new TrendObjekt(null, 0), new Object()));
			Assert.fail("Max steigend geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
	}

	/**
	 * testet die Ausführung des Operation "maxKonstant".
	 */
	@Test
	public void testPerformMaxKonstant() {
		operator = TrendOperatoren.MAXKONSTANT;
		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get());
			Assert.fail("Max konstant geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(new Object()));
			Assert.fail("Max konstant geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
		Assert.assertEquals(0L,
				TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(new TrendObjekt(null, 0))));

		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(new TrendObjekt(null, 0), new Object()));
			Assert.fail("Max konstant geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
	}

	/**
	 * testet die Monotonie des Trendobjekts.
	 *
	 * @param op
	 *            die zu testende Operation
	 * @param wert1
	 *            der erste Wert
	 * @param wert2
	 *            der nachfolgende Wert
	 */
	public void testeMonotonie(final Operator op, final int wert1, final int wert2) {
		operator = op;
		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get());
			Assert.fail("Wert geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(new Object()));
			Assert.fail("Wert geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
		final TrendObjekt trend = new TrendObjekt(null, 0);
		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(trend, 2));
			Assert.fail("Wert geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}

		trend.addWert(wert1, null);
		Assert.assertEquals(LogischerWert.WAHR, TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(trend)));

		trend.addWert(wert2, null);
		Assert.assertEquals(LogischerWert.WAHR, TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(trend)));

		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(trend, new Object()));
			Assert.fail("Wert geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
		Assert.assertEquals(LogischerWert.WAHR,
				TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(trend, 2)));
		Assert.assertEquals(LogischerWert.FALSCH,
				TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(trend, new ZeitDauer(0L))));

		try {
			TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(trend, new ZeitDauer(0L), new Object()));
			Assert.fail("Wert geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
		Assert.assertEquals(LogischerWert.WAHR,
				TrendHandlerTest.HANDLER.perform(operator, OperandenListe.get(trend, 2, new Zeitstempel())));
		Assert.assertEquals(LogischerWert.FALSCH, TrendHandlerTest.HANDLER.perform(operator,
				OperandenListe.get(trend, new ZeitDauer(10000L), new Zeitstempel())));

		try {
			TrendHandlerTest.HANDLER.perform(operator,
					OperandenListe.get(trend, new ZeitDauer(10000L), new Zeitstempel(10000)));
			Assert.fail("Wert geliefert");
		} catch (final ArgumentFehler e) {
			// Exception erwartet
		}
	}

	/**
	 * testet die Ausführung des Operation "steigend".
	 */
	@Test
	public void testPerformSteigend() {
		testeMonotonie(TrendOperatoren.STEIGEND, 12, 13);
	}

	/**
	 * testet die Ausführung des Operation "fallend".
	 */
	@Test
	public void testPerformFallend() {
		testeMonotonie(TrendOperatoren.FALLEND, 13, 12);
	}

	/**
	 * testet die Ausführung des Operation "konstant".
	 */
	@Test
	public void testPerformKonstant() {
		testeMonotonie(TrendOperatoren.KONSTANT, 12, 12);
	}
}
