/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.zeit;

import de.bsvrz.sys.funclib.bitctrl.interpreter.Operator;

/**
 * Operatoren mit denen Zeitwerte verarbeitet werden können.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public final class ZeitstempelOperatoren {

	/**
	 * der Operator zum Anlegen eines neuen Zeitstempel-Objekts.
	 */
	public static final Operator KONSTRUKTOR = Operator.getOperator("zeitstempel");

	/**
	 * der Operator zum Anlegen eines neuen Zeitstempel-Objekts.
	 */
	public static final Operator ZEITBEREICH_KONSTRUKTOR = Operator.getOperator("zeitbereich");

	/**
	 * der Operator zum Umwandeln eines Zeitstempels in eine Zeichenkette.
	 */
	public static final Operator FORMAT = Operator.getOperator("format");

	/**
	 * addiert zwei zeitbezogene Werte.<br>
	 * Erlaubt sind folgende Kombinationen:
	 * <ol>
	 * <li>Zeitstempel + Zeitdauer = Zeitstempel</li>
	 * <li>Zeitdauer + Zeitstempel = Zeitstempel</li>
	 * <li>Zeitdauer + Zeitdauer = Zeitdauer</li>
	 * </ol>
	 */
	public static final Operator PLUS = Operator.getOperator("+");

	/**
	 * subtrahiert zwei zeitbezogene Werte. Erlaubt sind folgende Kombinationen:
	 * <ol>
	 * <li>Zeitstempel - Zeitstempel = Zeitdauer</li>
	 * <li>Zeitstempel - Zeitdauer = Zeitstempel</li>
	 * <li>Zeitdauer - Zeitdauer = Zeitdauer</li>
	 * </ol>
	 *
	 */
	public static final Operator MINUS = Operator.getOperator("-");

	/**
	 * die Liste aller Zeitstempeloperatoren.
	 */
	public static final Operator[] OPERATOREN = { ZeitstempelOperatoren.KONSTRUKTOR,
			ZeitstempelOperatoren.ZEITBEREICH_KONSTRUKTOR, ZeitstempelOperatoren.PLUS, ZeitstempelOperatoren.MINUS,
			ZeitstempelOperatoren.FORMAT };

	/** privater Konstruktor für Utility-Klasse. */
	private ZeitstempelOperatoren() {
		super();
	}
}
