/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.uda;

import java.util.ResourceBundle;
import java.util.logging.Level;

import de.bsvrz.sys.funclib.bitctrl.daf.LogNachricht;
import de.bsvrz.sys.funclib.debug.Debug;
import de.bsvrz.sys.funclib.operatingMessage.MessageGrade;

/**
 * die allgemeinen Meldungen innerhalb der Softwareeinheit "Umfassende
 * Datenanalyse".
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public enum UdaMessage implements LogNachricht {

	/** Parameter: 1) das Datenobjekt. */
	WarningSetzenZeitAttribut(Debug.WARNING),

	/** Parameter: 1) das Mengenobjekt. */
	WarningUnerwartetesMengenUpdate(Debug.WARNING),

	/** Parameter: keine. */
	ErrorUdaModulTyp(Debug.ERROR),

	/** Parameter: 1) die Meldung. */
	ErrorArchivAnfrage(Debug.ERROR),

	/** Parameter: 1) der Name einer Datei. 2) die Fehlermeldung */
	ErrorDateisystem(Debug.ERROR),

	/** Parameter: 1) der Name des Skripts 2) die Fehlermeldung. */
	ErrorSkriptAnlegen(Debug.ERROR),

	/** Parameter: 1) der Name des Skriptlaufs 2) die Fehlermeldung. */
	ErrorSkriptlaufAnlegen(Debug.ERROR),

	/** Parameter: 1) der Name des Skriptlaufs 2) die Fehlermeldung. */
	ErrorSkriptlaufAktualisierung(Debug.ERROR),

	/** Parameter: 1) die Fehlermeldung. */
	WarningUnerwarteterAnmeldeeintrag(Debug.WARNING);

	/**
	 * das verwendete Ressource-Bundle.
	 */
	private static final ResourceBundle RESOURCE_BUNDLE = ResourceBundle.getBundle(UdaMessage.class.getCanonicalName());

	/** der Level mit dem die Meldung ausgegeben werden soll. */
	private Level level;

	/**
	 * Initialisiert das Objekt.
	 *
	 * @param level
	 *            der Log-Level.
	 */
	UdaMessage(final Level level) {
		this.level = level;
	}

	/**
	 * {@inheritDoc}.<br>
	 *
	 * @see de.bsvrz.sys.funclib.bitctrl.daf.LogNachricht#getBmvLevel()
	 */
	@Override
	public MessageGrade getBmvLevel() {
		MessageGrade result = null;
		if (level.equals(Debug.WARNING)) {
			result = MessageGrade.WARNING;
		} else if (level.equals(Debug.ERROR)) {
			result = MessageGrade.ERROR;
		}
		return result;
	}

	/**
	 * {@inheritDoc}.<br>
	 *
	 * @see de.bsvrz.sys.funclib.bitctrl.daf.LogNachricht#getLogLevel()
	 */
	@Override
	public Level getLogLevel() {
		return level;
	}

	/**
	 * {@inheritDoc}.
	 */
	@Override
	public ResourceBundle getResourceBundle() {
		return UdaMessage.RESOURCE_BUNDLE;
	}
}
